@@ -198,6 +198,7 @@ class ServiceNameCatalog:
         ServiceName("es", "ElasticsearchService"),
         ServiceName("events", "EventBridge"),
         ServiceName("firehose", "Firehose"),
+        ServiceName("fis", "FIS"),
         ServiceName("fms", "FMS"),
         ServiceName("forecast", "ForecastService"),
         ServiceName("forecastquery", "ForecastQueryService"),
@@ -248,10 +249,14 @@ class ServiceNameCatalog:
         ServiceName("lambda", "Lambda"),
         ServiceName("lex-models", "LexModelBuildingService"),
         ServiceName("lex-runtime", "LexRuntimeService"),
+        ServiceName("lexv2-models", "LexModelsV2"),
+        ServiceName("lexv2-runtime", "LexRuntimeV2"),
         ServiceName("license-manager", "LicenseManager"),
         ServiceName("lightsail", "Lightsail"),
         ServiceName("location", "LocationService"),
         ServiceName("logs", "CloudWatchLogs"),
+        ServiceName("lookoutequipment", "LookoutEquipment"),
+        ServiceName("lookoutmetrics", "LookoutMetrics"),
         ServiceName("lookoutvision", "LookoutforVision"),
         ServiceName("machinelearning", "MachineLearning"),
         ServiceName("macie", "Macie"),
@@ -270,6 +275,7 @@ class ServiceNameCatalog:
         ServiceName("mediatailor", "MediaTailor"),
         ServiceName("meteringmarketplace", "MarketplaceMetering"),
         ServiceName("mgh", "MigrationHub"),
+        ServiceName("mgn", "mgn"),
         ServiceName("migrationhub-config", "MigrationHubConfig"),
         ServiceName("mobile", "Mobile"),
         ServiceName("mq", "MQ"),
